# [{{ name }}]({{ homepage }}/book)

[![PyPI version](https://badge.fury.io/py/{{ name }}.svg)](https://badge.fury.io/py/{{ name }})
[![Apache 2.0 License](https://img.shields.io/badge/License-APACHEv2-brightgreen.svg)]({{ repository }}/blob/master/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/{{ name }}?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/{{ name }})
[![Coverage Status](https://coveralls.io/repos/github/cvxgrp/{{ name }}/badge.png?branch=main)](https://coveralls.io/github/cvxgrp/{{ name }}?branch=main)
